AC_DEFUN(AC_INTERNAL_ERROR,
[
	AC_MSG_ERROR([
	*** Internal error: $1.
	*** Please send this error message to temporal@gauge3d.org.])
])

AC_DEFUN(AC_GUF_TEST_PLATFORM,
[
dnl Define platform stuff ------------------------------------------------
dnl CPU test ----------

AC_MSG_CHECKING([CPU])
case ${target_cpu} in
	i*86)
		AC_MSG_RESULT([Intel x86 compatible])
		AC_DEFINE(PLATFORM_I386, 1, [Define if you CPU is x86-compatible])
		word_size=32
		endianness=little
		;;
	*powerpc*)
		AC_MSG_RESULT([Power PC])
		AC_DEFINE(PLATFORM_PPC, 1, [Define if you CPU is PowerPC-based])
		word_size=32
		endianness=big
		;;
	*)
		AC_MSG_RESULT([Unknown: ${target_cpu}])
		AC_MSG_ERROR([
*** Sorry, this CPU is not (yet) supported.  If you would like to port GUF to
*** this CPU, please e-mail me at <temporal@gauge3d.org>, and I will be happy
*** to assist you in this endeavor.
*** If you believe this error is incorrect, try using the "--target" parameter
*** for configure. (Type \"configure --help\" for more info) ])
		;;
esac

case x${word_size} in
	x32)
		AC_DEFINE(PLATFORM_32BIT, 1, [Define if you have a 32-bit CPU])
		;;
	x64)
		AC_DEFINE(PLATFORM_64BIT, 1, [Define if you have a 64-bit CPU])
		;;
	*)
		AC_INTERNAL_ERROR([bad CPU word size \"${word_size}\".])
		;;
esac

case x${endianness} in
	xlittle)
		AC_DEFINE(PLATFORM_LITTLE_ENDIAN, 1, [Define if you have a 32-bit CPU])
		;;
	xbig)
		AC_DEFINE(PLATFORM_BIG_ENDIAN, 1, [Define if you have a 64-bit CPU])
		;;
	*)
		AC_INTERNAL_ERROR([bad endianness \"${endianness}\".])
		;;
esac


dnl OS test -----------

AC_MSG_CHECKING([operating system])
case ${target_os} in
	*linux*)
		AC_MSG_RESULT([GNU/Linux])
		AC_DEFINE(PLATFORM_LINUX, 1, [Define if your operating system is Linux-based])
		is_posix=yes
		;;
	*beos*)
		AC_MSG_RESULT([Be OS])
		AC_DEFINE(PLATFORM_BEOS, 1, [Define if your operating system is Be OS])
		is_posix=yes
		;;
	*cygwin*)
		AC_MSG_RESULT([CygWin (Windows)])
		AC_MSG_ERROR(
[*** Due to licensing restrictions, CygWin is not supported as a host platform
*** for GufBuild.  Instead, you should use MinGW.  See README.txt for more
*** info. ])
		;;
	*mingw*)
		AC_MSG_RESULT([MinGW (Windows)])
		AC_MSG_ERROR(
[*** You should not be using this script in Windows.  You should be
*** running "configure.bat" instead.  Then, run "build.bat".  See
*** README.txt for more info. ])
		;;
	*darwin*)
		AC_MSG_RESULT([Apple Darwin / MacOSX])
		AC_DEFINE(PLATFORM_DARWIN, 1, [Define if your operating system is Darwin-based])
		is_posix=yes
		;;
	*)
		AC_MSG_RESULT([${target_os}])

		AC_MSG_ERROR([
*** Sorry, this OS is not (yet) supported.  If you would like to port GUF to
*** this OS, please e-mail me at <temporal@gauge3d.org>, and I will be happy
*** to assist you in this endeavor.
*** If you believe this error is incorrect, try using the "--target" parameter
*** for configure. (Type \"configure --help\" for more info) ])
		;;
esac

if test x$is_posix = xyes; then
	AC_DEFINE(PLATFORM_POSIX, 1, [Define if your operating system is POSIX compliant.])
fi

dnl ----------------------------------------------------------------------
])
