/* GUF Build - A Semi-Replacement for Make
 * Copyright (C) 2001 Kenton Varda
 * <http://www.gauge3d.org/guf>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

// ===================================================================

#ifndef gufbuild_Binary_H__INCLUDED__
#define gufbuild_Binary_H__INCLUDED__

// includes ==========================================================
#include "Common.h"
#include "Buildable.h"

namespace gufbuild {

// class definition ==================================================
class Binary: public Buildable
{
public:
	Binary(string name, bool isLibrary, bool notGuf, string sourcefile, int linenum);
	~Binary();

	BuildResult Build();

	bool Check();
	bool Clean();
	bool Document();

	void GetRequiredHeaders(vector<string >& list);
	void GetRequiredLibraries(vector<string >& list);

	void GetObjects(vector<string >& objects);

	string GetName();
	string GetNameWithUnderscores();

	void AddObject(Buildable* object, bool main);

	void AddCFlag(string cflag);
	void AddLdFlag(string ldflag);

private:
	string mName;

	bool mIsLibrary;
	bool mNotGuf;

	vector<Buildable* > mObjects;
	Buildable* mMainObject;

	string mSourceFile;
	int mLineNum;

	vector<string > mCFlags;
	vector<string > mLdFlags;

	bool mBuilt;
	bool mCleaned;
	bool mChecked;
	bool mDocumented;

	BuildResult mBuildResult;
	bool mCleanResult;
	bool mCheckResult;
	bool mDocumentResult;

	//disable copy
	Binary(const Binary& other);
	void operator=(const Binary& other);
};

} //namespace gufbuild

#endif //included
